==> tine20-allinone_2020.03.4.tar.bz2: Addressbook/js/Addressbook-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: bg\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Бизнес контакти"

, "Organisation / Unit"
: "Организация / Отдел"

, "Business Address"
: "Адрес на фирмата"

, "Email"
: "Имейл"

, "Telephone Work"
: "Служебен телефон"

, "Telephone Cellphone"
: "Мобилен телефон"

, "Telephone Car"
: "Телефон (кола)"

, "Telephone Fax"
: "Телефонен факс"

, "Telephone Page"
: "Телефонна страница"

, "URL"
: "URL"

, "Role"
: "Длъжност"

, "Room"
: "Стая"

, "Assistant"
: "Асистент"

, "Assistant Telephone"
: "Асистент-телефон"

, "Private Contact Data"
: "Данни за личен контакт"

, "Private Address"
: "Личен адрес"

, "Email Home"
: "Имейл (личен адрес)"

, "Telephone Home"
: "Телефон  (личен номер)"

, "Telephone Cellphone Private"
: "Телефон (личен)"

, "Telephone Fax Home"
: "Факс  (личен номер)"

, "URL Home"
: "URL  (личен адрес)"

, "Other Data"
: "Други данни"

, "Birthday"
: "Дата на раждане"

, "Job Title"
: "Длъжност"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  ""
 ,""

]
, "Percent"
: ""

, "Description"
: "Описание (допълнителна информаця)"

, "Members"
: ""

, "Type"
: "Вид"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  ""
 ,""

]
, "Contact, Contacts"
: [
  "Контакт"
 ,"Контакта"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Държава"

, "City"
: "Град"

, "Postalcode"
: "Пощенски код"

, "Region"
: "Област"

, "Street"
: "Улица"

, "Street 2"
: "Улица 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Народност (рерсонална)"

, "City (private)"
: "Град (личен адрес)"

, "Postalcode (private)"
: "Пощенски код (личен адрес)"

, "Region (private)"
: "Област (приват)"

, "Street (private)"
: "Улица (личен адрес)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Имейл (личен адрес)"

, "Free/Busy URI"
: ""

, "Geo"
: "Географско местонахождение / Координати"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Бележки"

, "Last Name"
: "Фамилия"

, "Display Name"
: "Име"

, "Full Name"
: "Пълно име"

, "First Name"
: "Име"

, "Middle Name"
: "Бащино име"

, "Title"
: "Титла"

, "Suffix"
: "Допълнително име"

, "Company"
: "Фирма"

, "Unit"
: "Отдел"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Длъжност"

, "Salutation"
: "Поздрав"

, "syncBackendIds"
: ""

, "Car phone"
: "Телефон (кола)"

, "Mobile"
: "Мобилен телефон"

, "Mobile (private)"
: "Мобилен телефон (личен)"

, "Fax"
: "Факс"

, "Fax (private)"
: "Факс  (личен)"

, "Phone (private)"
: "Телефон (личен)"

, "Pager"
: "Пейджер"

, "Phone"
: "Телефон"

, "Timezone"
: "Часова зона"

, "Web"
: "Уеб"

, "URL (private)"
: "URL (личена страница)"

, "Label"
: ""

, "Lists"
: ""

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Информаця за контакт"

, "Company Address"
: "Фирмен адрес"

, "New Contact"
: ""

, "ID"
: ""

, "Name"
: ""

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: ""

, "Contact of a user account"
: ""

, "No name"
: ""

, "Business"
: ""

, "Private"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Тагове"

, "List Roles"
: ""

, "Street (Company Address)"
: ""

, "Street 2 (Company Address)"
: ""

, "City (Company Address)"
: ""

, "Region (Company Address)"
: ""

, "Postal Code (Company Address)"
: ""

, "Country (Company Address)"
: ""

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: ""

, "Street 2 (Private Address)"
: ""

, "City (Private Address)"
: ""

, "Region (Private Address)"
: ""

, "Postal Code (Private Address)"
: ""

, "Country (Private Address)"
: ""

, "Company Communication"
: ""

, "Private Communication"
: ""

, "E-Mail"
: "Имейл"

, "E-Mail (private)"
: "Имейл (личен адрес)"

, "Web (private)"
: ""

, "Contacts"
: "Контакти"

, "Addressbooks"
: ""

, "User Account"
: ""

, "Quick Search"
: ""

, "Postal Code"
: "Пощенски код"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Вкарай описание"

, "{0} must be given"
: ""

, "Member of List"
: ""

, "Map"
: "Карта"

, "Company address"
: ""

, "Private address"
: ""

, "CardDAV URL"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Персонална информаця"

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: ""

, "Default Addressbook"
: ""

, "The default addressbook for new contacts"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "Господин"

, "Ms"
: "Госпожа"

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Contact CSV import from mac address book"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: ""

, "manage shared addressbooks"
: "Споделени списъци на адреси"

, "Create new shared addressbook folders"
: "Създай нови папки за споделени адресни списъци"

, "manage shared addressbook favorites"
: ""

, "Create or update shared addressbook favorites"
: ""

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "%s's лични адреси"

, "All contacts I have read grants for"
: ""

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "Internal Contacts"
: "Международни контакти"

, "List"
: ""

, "Addressbook"
: ""

, "Contact"
: "Контакт"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nLanguage: bg\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "Карта"

, "Preferred Address"
: ""

, "Personal Information"
: "Персонална информаця"

, "Salutation"
: "Поздрав"

, "Title"
: "Титла"

, "Short Name"
: ""

, "First Name"
: "Име"

, "Middle Name"
: "Бащино име"

, "Last Name"
: "Фамилия"

, "Company"
: "Фирма"

, "Unit"
: "Отдел"

, "Display Name"
: "Име"

, "Industry, Industries"
: [
  ""
 ,""

]
, "Job Title"
: "Длъжност"

, "Birthday (private)"
: ""

, "Contact Information"
: "Информаця за контакт"

, "Phone"
: "Телефон"

, "Mobile"
: "Мобилен телефон"

, "Fax"
: "Факс"

, "Phone (private)"
: "Телефон (личен)"

, "Mobile (private)"
: "Мобилен телефон (личен)"

, "Fax (private)"
: "Факс  (личен)"

, "E-Mail"
: "Имейл"

, "E-Mail (private)"
: "Имейл (личен адрес)"

, "Web"
: "Уеб"

, "Company Address"
: "Фирмен адрес"

, "Street"
: "Улица"

, "Street 2"
: "Улица 2"

, "Region"
: "Област"

, "Postal Code"
: "Пощенски код"

, "City"
: "Град"

, "Country"
: "Държава"

, "Private Address"
: "Личен адрес"

, "Description"
: "Описание (допълнителна информаця)"

, "Enter description"
: "Вкарай описание"

, "Groups"
: ""

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Contact, Contacts"
: [
  "Контакт"
 ,"Контакта"

]
, "Members"
: ""

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: ""

, "CardDAV URL"
: ""

, "New Contact"
: ""

, "Addressbook, Addressbooks"
: [
  ""
 ,""

]
, "ID"
: ""

, "Name"
: ""

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Private"
: ""

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""
 ,""

]
, "List Personal Grant, List Personal Grants"
: [
  ""
 ,""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: ""

, "Suffix"
: "Допълнително име"

, "Birthday"
: "Дата на раждане"

, "Job Role"
: "Длъжност"

, "Room"
: "Стая"

, "Street (Company Address)"
: ""

, "Street 2 (Company Address)"
: ""

, "City (Company Address)"
: ""

, "Region (Company Address)"
: ""

, "Postal Code (Company Address)"
: ""

, "Country (Company Address)"
: ""

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: ""

, "Street 2 (Private Address)"
: ""

, "City (Private Address)"
: ""

, "Region (Private Address)"
: ""

, "Postal Code (Private Address)"
: ""

, "Country (Private Address)"
: ""

, "Company Communication"
: ""

, "Private Communication"
: ""

, "Web (private)"
: ""

, "Contacts"
: "Контакти"

, "Addressbooks"
: ""

, "User Account"
: ""

, "Quick Search"
: ""

, "Type"
: "Вид"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "List, Lists"
: [
  ""
 ,""

]
, "Lists"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: ""

, "Contact of a user account"
: ""

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Тагове"

, "Full Name"
: "Пълно име"

, "Postalcode"
: "Пощенски код"

, "Street (private)"
: "Улица (личен адрес)"

, "City (private)"
: "Град (личен адрес)"

, "Region (private)"
: "Област (приват)"

, "Postalcode (private)"
: "Пощенски код (личен адрес)"

, "Country (private)"
: "Народност (рерсонална)"

, "Email"
: "Имейл"

, "Car phone"
: "Телефон (кола)"

, "Pager"
: "Пейджер"

, "Email (private)"
: "Имейл (личен адрес)"

, "URL (private)"
: "URL (личена страница)"

, "Note"
: "Бележки"

, "Timezone"
: "Часова зона"

, "Geo"
: "Географско местонахождение / Координати"

, "Select list"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Company address"
: ""

, "Private address"
: ""

, "Member E-Mails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: ""

, "Default Addressbook"
: ""

, "The default addressbook for new contacts"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "Господин"

, "Ms"
: "Госпожа"

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "%s's лични адреси"

, "Business Contact Data"
: "Бизнес контакти"

, "Organisation / Unit"
: "Организация / Отдел"

, "Business Address"
: "Адрес на фирмата"

, "Telephone Work"
: "Служебен телефон"

, "Telephone Cellphone"
: "Мобилен телефон"

, "Telephone Car"
: "Телефон (кола)"

, "Telephone Fax"
: "Телефонен факс"

, "Telephone Page"
: "Телефонна страница"

, "URL"
: "URL"

, "Role"
: "Длъжност"

, "Assistant"
: "Асистент"

, "Assistant Telephone"
: "Асистент-телефон"

, "Private Contact Data"
: "Данни за личен контакт"

, "Email Home"
: "Имейл (личен адрес)"

, "Telephone Home"
: "Телефон  (личен номер)"

, "Telephone Cellphone Private"
: "Телефон (личен)"

, "Telephone Fax Home"
: "Факс  (личен номер)"

, "URL Home"
: "URL  (личен адрес)"

, "Other Data"
: "Други данни"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Contact CSV import from mac address book"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: ""

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "Международни контакти"

, "All contacts I have read grants for"
: ""

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: "Споделени списъци на адреси"

, "Create new shared addressbook folders"
: "Създай нови папки за споделени адресни списъци"

, "manage shared addressbook favorites"
: ""

, "Create or update shared addressbook favorites"
: ""

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "Industry"
: ""

, "Contact"
: "Контакт"

, "Addressbook"
: ""

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
